# This file is part of Xpra.
# Copyright (C) 2013 Antoine Martin <antoine@devloop.org.uk>
# Xpra is released under the terms of the GNU GPL v2, or, at your option, any
# later version. See the file COPYING for details.

#magic value to distinguish exit code for upgrading (True==1)
#and exiting:
EXITING_CODE = 2
